@@ -71,14 +71,12 @@ class Job(JenkinsBase):
             total_wait = 0
             while self.is_queued():
                 log.info( "Waited %is for %s to begin..." % ( total_wait, self.id() ) )
-                time.sleep( invoke_block_delay )
+                sleep( invoke_block_delay )
                 total_wait += invoke_block_delay
             if self.is_running():
                 running_build = self.get_last_build()
                 running_build.block_until_complete( delay=invoke_pre_check_delay )
-                assert running_build.is_good()
-            else:
-                assert self.get_last_buildnumber() > original_build_no, "Job does not appear to have run."
+            assert self.get_last_buildnumber() > original_build_no, "Job does not appear to have run."
         else:
             if self.is_queued():
                 log.info( "%s has been queued." % self.id() )
@@ -93,6 +91,8 @@ class Job(JenkinsBase):
         """Gets a buildid for a given type of build"""
         KNOWNBUILDTYPES=["lastSuccessfulBuild", "lastBuild", "lastCompletedBuild"]
         assert buildtype in KNOWNBUILDTYPES
+        if self._data[buildtype] == None:
+            return None
         buildid = self._data[buildtype]["number"]
         assert type(buildid) == int, "Build ID should be an integer, got %s" % repr( buildid )
         return buildid
@@ -146,11 +146,19 @@ class Job(JenkinsBase):
 
     def get_last_build( self ):
         """
-        Get the last good build
+        Get the last build
         """
         bn = self.get_last_buildnumber()
         return self.get_build( bn )
 
+    def get_last_build_or_none(self):
+        """
+        Get the last build or None if there is no builds
+        """
+        bn = self.get_last_buildnumber()
+        if bn is not None:
+            return self.get_build(bn)
+
     def get_last_completed_build( self ):
         """
         Get the last build regardless of status
@@ -192,11 +200,17 @@ class Job(JenkinsBase):
     def is_running(self):
         self.poll()
         try:
-            return self.get_last_build().is_running()
+            build = self.get_last_build_or_none()
+            if build is not None:
+                return build.is_running()
         except NoBuildData:
             log.info("No build info available for %s, assuming not running." % str(self) )
-            return False
+        return False
 
     def get_config(self):
         '''Returns the config.xml from the job'''
         return self.hit_url("%(baseurl)s/config.xml" % self.__dict__)
+
+    def update_config(self, config):
+        '''Update the config.xml to the job'''
+        return self.post_data("%(baseurl)s/config.xml" % self.__dict__, config)
